@@ -647,6 +647,11 @@ latex_elements['preamble'] = r"""
 \makeatother
 """
 
+# Enable "hard wrapping" long code lines (only applies if breaking
+# long codelines at spaces or other suitable places failed, typically
+# this is for long decimal expansions or possibly long string identifiers)
+latex_elements['sphinxsetup'] = "verbatimforcewraps=true"
+
 # Documents to append as an appendix to all manuals.
 # latex_appendices = []
 
@@ -670,6 +675,7 @@ for macro in sage_latex_macros():
     # used when building html version
     pngmath_latex_preamble += macro + '\n'
 
+
 # ------------------------------------------
 # add custom context variables for templates
 # ------------------------------------------
@@ -707,16 +713,18 @@ def add_page_context(app, pagename, templatename, context, doctree):
             f = importlib.import_module(pagename.replace('/','.')).__file__
             suffix = '.py' if not f or f.endswith('.py') else '.pyx'
             context['page_source_suffix'] = suffix
-            context['theme_source_view_link'] = os.path.join(source_repository, f'blob/develop/src', '{filename}')
-            context['theme_source_edit_link'] = os.path.join(source_repository, f'edit/develop/src', '{filename}')
+            context['theme_source_view_link'] = os.path.join(source_repository, 'blob/develop/src', '{filename}')
+            context['theme_source_edit_link'] = os.path.join(source_repository, 'edit/develop/src', '{filename}')
 
 
 dangling_debug = False
 
+
 def debug_inf(app, message):
     if dangling_debug:
         app.info(message)
 
+
 def call_intersphinx(app, env, node, contnode):
     r"""
     Call intersphinx and make links between Sage manuals relative.
@@ -750,6 +758,7 @@ def call_intersphinx(app, env, node, contnode):
         debug_inf(app, "---- Intersphinx: %s not Found" % node['reftarget'])
     return res
 
+
 def find_sage_dangling_links(app, env, node, contnode):
     r"""
     Try to find dangling link in local module imports or all.py.
@@ -860,6 +869,7 @@ skip_picklability_check_modules = [
     '__builtin__',
 ]
 
+
 def check_nested_class_picklability(app, what, name, obj, skip, options):
     """
     Print a warning if pickling is broken for nested classes.
@@ -880,6 +890,7 @@ def check_nested_class_picklability(app, what, name, obj, skip, options):
                          'sage.misc.nested_class.NestedClassMetaclass.' % (
                         v.__module__ + '.' + name + '.' + nm))
 
+
 def skip_member(app, what, name, obj, skip, options):
     """
     To suppress Sphinx warnings / errors, we
@@ -955,16 +966,17 @@ class SagecodeTransform(SphinxTransform):
 
     def apply(self):
         if self.app.builder.tags.has('html') or self.app.builder.tags.has('inventory'):
-            for node in self.document.findall(nodes.literal_block):
+            for node in list(self.document.findall(nodes.literal_block)):
                 if node.get('language') is None and node.astext().startswith('sage:'):
                     from docutils.nodes import container as Container, label as Label, literal_block as LiteralBlock, Text
                     from sphinx_inline_tabs._impl import TabContainer
                     parent = node.parent
                     index = parent.index(node)
                     prev_node = node.previous_sibling()
-                    if isinstance(node.previous_sibling(), TabContainer):
+                    if isinstance(prev_node, TabContainer):
                         # Make sure not to merge inline tabs for adjacent literal blocks
-                        parent.insert(index, Text(''))
+                        parent.insert(index, nodes.paragraph())
+                        prev_node = parent[index]
                         index += 1
                     parent.remove(node)
                     # Tab for Sage code
